from yearmaps.providers.BBDCProvider import BBDCProvider
from yearmaps.providers.BilibiliProvider import BilibiliProvider
from yearmaps.providers.CodeforcesProvider import CodeforcesProvider
from yearmaps.providers.GitHubProvider import GitHubProvider

providers = [BBDCProvider, BilibiliProvider, CodeforcesProvider, GitHubProvider]
